# mdtob64--markdown图片转base64程序

---

## 导入包使用 from mdtob64.mdtob64 import mdtob64

## 命令行运行 mdtob64

## 需要填写两个参数
### 文件路径需要包括文件本身，需要写上格式.md
### 新文件默认存放当前目录下，只需要写上文件名

## 路径或者文件名任意一个输入空则视为取消操作

##v0.0.4
### 增加了标识，备份的文件也可以直接追加内容